<!--
%\VignetteEngine{knitr::knitr}
%\VignetteIndexEntry{Using Trendlines with googleVis}
-->
# Using Trendlines with googleVis

A trendline is a line superimposed on a chart revealing the overall 
direction of the data. Google Charts can automatically generate 
trendlines for Scatter Charts, Bar Charts, Column Charts and Line Charts.

For more details visit: 
https://developers.google.com/chart/interactive/docs/gallery/trendlines

```{r setOptions, message=FALSE, echo=FALSE}
library(googleVis)
library(knitr)
op <- options(gvis.plot.tag='chart')
read_demo('Trendlines', 'googleVis')
```

## Linear trend line
```{r LinearTrend, results='asis', tidy=FALSE}
```

## Exponential trend line with equation shown in legend
```{r ExponentialTrend, results='asis', tidy=FALSE}
```

## Add trend line to column chart
```{r ColumnChartWithTrendline, results='asis', tidy=FALSE}
```

## Changing labels in legend
```{r DifferentLabels, results='asis', tidy=FALSE}
```
